GEOMETOR • model
================

.. image:: _static/splash.png

.. include:: intro.rst

recent logs
-----------

.. collection::
   :type: log
   :sort: date
   :reverse:
   :limit: 5



.. toctree::
   :hidden:
   :maxdepth: 2

   mission/index.rst
   usage/index.rst
   demos/index.rst

   modules/index.rst
   log/index.rst
   refs/index.rst
   glossary.rst
   connect.rst
   todos.rst
   changelog.rst
   about.rst


indices
-------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
